@@ -1,6 +1,7 @@
 from django.db.models import Field
 from django.forms import widgets
 from s3direct.widgets import S3DirectEditor
+from django.conf import settings
 
 
 class S3DirectField(Field):
@@ -15,4 +16,9 @@ class S3DirectField(Field):
     def formfield(self, **kwargs):
         defaults = {'widget': self.widget}
         defaults.update(kwargs)
-        return super(S3DirectField, self).formfield(**defaults)
\ No newline at end of file
+        return super(S3DirectField, self).formfield(**defaults)
+        
+
+if 'south' in settings.INSTALLED_APPS:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^s3direct\.fields\.S3DirectField"])
\ No newline at end of file
